<?php

/**
  * SquirrelMail Mail Alias Plugin
  * Copyright (C) 2004,2005 Graeme C Neatham <graeme@promptpost.com>
  * This program is licensed under GPL. See COPYING for details
  *
  */

if(!defined('SM_PATH'))
             define('SM_PATH', '../../');

/**
  * Register plugin hooks
  *
  */
function squirrelmail_plugin_init_mail_alias() {
    global $squirrelmail_plugin_hooks;

    $squirrelmail_plugin_hooks['optpage_register_block']['mail_alias'] = 'mail_alias_optpage_register_block';
}

function mail_alias_optpage_register_block() {

   include_once(SM_PATH . 'plugins/mail_alias/functions.php');
   mail_alias_optpage_register_block_do();
}

function mail_alias_version() {

   return '2.0.0';
}
?>
